{"tmpList":[{"cxbj":"0","date":"二○二○年七月二十二日","dateDigit":"2020年7月22日","dateDigitSeparator":"2020-7-22","day":"22","fxbj":"0","jgpxzd":"1","jxb_id":"A86B79F220E93BC0E055F8163ED16360","jxbmc":"(2020-2021-1)-CS241-2","jxbzls":"1","kch":"CS241","kch_id":"CS241","kcmc":"问题求解与实践","kcrow":"1","kklxdm":"01","listnav":"false","localeKey":"zh_CN","month":"7","pageable":true,"queryModel":{"currentPage":1,"currentResult":0,"entityOrField":false,"limit":15,"offset":0,"pageNo":0,"pageSize":15,"showCount":10,"sorts":[],"totalCount":0,"totalPage":0,"totalResult":0},"rangeable":true,"totalResult":"0","userModel":{"monitor":false,"roleCount":0,"roleKeys":"","roleValues":"","status":0,"usable":false},"xf":"3.0","xxkbj":"0","year":"2020","yxzrs":"59"}],"sfxsjc":"1"}